import logging


logger = logging.getLogger(__name__)


def create_favicon_svg_file(file_path, hue):
    logger.debug('Writing favicon.svg file.')

    ## The SVG is from https://feathericons.com/
    svg = f"""
    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="hsl({hue}, 65%, 83%)" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
        <path d="M2 3h6a4 4 0 0 1 4 4v14a3 3 0 0 0-3-3H2z"></path>
        <path d="M22 3h-6a4 4 0 0 0-4 4v14a3 3 0 0 1 3-3h7z"></path>
    </svg>
    """
    with open(file_path, 'w') as f:
        f.write(svg)

    logger.debug(f'Done, created at {repr(file_path)}.')


import logging
import os

from nics.main.constants import __version__


logger = logging.getLogger(__name__)


def get_text(load, dock, container, git_name, git_email, gh_repo_name):
    ## Note: Make sure there is only one occurrence of the 'container: .*' word
    ##       in the rebuild-docs.yml file because it will be used by the 'upgrade' command.
    return f"""
# This file was generated by NICS ({__version__}).
# Documentation: https://github.com/nvfp/now-i-can-sleep

name: Rebuild documentation

on:
  push:
    branches:
      - {load}

    paths:
      - '{container}/**'  # Only rebuild if '{container}/' folder is modified

      # When using 'use-repo-readme' keyword in 'tree/index.md'
      - README.md
      - readme.md

  # Allows you to run this workflow manually from the Actions tab
  workflow_dispatch:

jobs:
  NICS-rebuild:
    runs-on: ubuntu-latest
    permissions:
      contents: write
    steps:
      - name: Run
        uses: nvfp/now-i-can-sleep@{__version__}
        with:
          load: {load}
          dock: {dock}
          container: {container}
          git-name: {git_name}
          git-email: {git_email}
          gh-repo-name: {gh_repo_name}
          nics-version: {__version__}
"""


def workflow_writer(load_path, load, dock, container, git_name, git_email, gh_repo_name):
    logger.debug('Writing rebuild-docs.yml file.')

    file_path = os.path.join(load_path, '.github', 'workflows', 'rebuild-docs.yml')

    ## Handle missing intermediate directories
    workflows_dir = os.path.dirname(file_path)
    logger.debug(f'Creating dirs {repr(workflows_dir)}.')
    os.makedirs(workflows_dir, exist_ok=True)

    text = get_text(load, dock, container, git_name, git_email, gh_repo_name)
    with open(file_path, 'w') as f:
        f.write(text)

    logger.debug(f'Done, {repr(file_path)} file is created.')




def get_user_details():

    ## Intro
    print('Welcome to NICS!')
    
    class usr: ...

    usr.load = input('Enter the main branch name (e.g. master): ')
    usr.dock = input('Enter the documentation branch name (e.g. docs): ')
    usr.container = input('Enter the documentation folder name (e.g. docs): ')
    
    usr.author = input('Enter your name: ')
    usr.git_name = input('Enter your git username: ')
    usr.git_email = input('Enter your git email: ')
    
    usr.gh_username = input('Enter your GitHub username: ')
    usr.gh_repo_name = input('Enter this GitHub repository name: ')

    return usr


try:
    from nics.main import main
except ModuleNotFoundError:  # This exception occurred during development ('nics' isn't installed via pip)
    from main import main


if __name__ == '__main__':
    main()


import logging
import os
import shutil

from nics.main.constants import TEMPLATE_DOCS_DIR_PTH


logger = logging.getLogger(__name__)


def copy_template(load_path, container):
    logger.debug('Copying doc template.')

    src = TEMPLATE_DOCS_DIR_PTH
    dst = os.path.join(load_path, container)
    shutil.copytree(src, dst)

    logger.debug(f'Done, copied from {repr(src)} to {repr(dst)}.')


import os

from nics.main.utils.ensure_a_git_repo import ensure_a_git_repo
from nics.main.cmd_upgrade.checks import check_rebuild_docs_yml_existence, check_container_clues, check_upgrade_status
from nics.main.cmd_upgrade.where_is_the_container import where_is_the_container
from nics.main.cmd_upgrade.gather_settings import gather_settings
from nics.main.cmd_init.loading.workflow_writer import workflow_writer
from nics.main.cmd_init.loading.settings_writer import settings_writer


def run():
    
    load_path = os.getcwd()

    ## Check
    ensure_a_git_repo(load_path)

    ## Check
    check_rebuild_docs_yml_existence(load_path)

    ## Get container
    CONTAINER = where_is_the_container(load_path)

    ## Check
    check_container_clues(load_path, CONTAINER)

    ## New settings key-value pairs
    cfg = gather_settings(load_path, CONTAINER)

    ## Check
    check_upgrade_status(cfg._nics_version)

    ## Update rebuild-docs.yml
    workflow_writer(
        load_path,
        cfg._load, cfg._dock, cfg._container, cfg._git_name, cfg._git_email, cfg._gh_repo_name
    )

    ## Update settings.txt
    settings_writer(
        load_path,
        cfg.author, cfg.custom_license, cfg.color_hue, cfg.lowercase_the_url, cfg.show_credit, cfg.char_map,
        cfg._git_name, cfg._git_email, cfg._gh_username, cfg._gh_repo_name, cfg._load, cfg._dock, cfg._container
    )

    ## For end-users
    print('Upgrade complete!')


import os


def ensure_a_git_repo(dir_path):

    if not os.path.isdir(dir_path):
        raise NotADirectoryError(f'Not a dir: {repr(dir_path)}')

    if '.git' not in os.listdir(dir_path):
        raise NotADirectoryError(f'.git folder not found in {repr(dir_path)}.')